==> wowit-0.3.158.tar.gz: lib/Widget/editor_widget/editor_widget.dart <==
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:wowit/Controller/baseController.dart';
import 'package:wowit/Widget/baseWidgets.dart';
import 'package:wowit/methods.dart';

import '../../message.dart';
import 'view/editor_screen.dart';

abstract class EditorWidget<T extends BaseController> extends BaseWidget<T> {
  final String title;
  final Color color;
  final bool isShowAppBar;
  final EditorController _editorController;
  final List<Widget> actionAppbar;

  EditorWidget(
    BaseController baseController, {
    Key key,
    this.title,
    this.color,
    this.isShowAppBar = true,
    List<EditorItem> editorItems,
    Map<String, Object> initialDataEntity,
    @required String onSaveProcedure,
    this.actionAppbar,
  })  : _editorController =
            EditorController(initialDataEntity, onSaveProcedure, editorItems),
        super(baseController as T);

  Widget getEditorControlView(BuildContext buildContext,
      EditorController editorController, BaseController baseController);

  void onBack() {
    Get.back();
  }

  Widget _getEditorView(BuildContext context, BaseController baseController) {
    return EditorScreen(
        editorControlView:
            getEditorControlView(context, _editorController, baseController),
        editorController: _editorController,
        title: this.title,
        onBack: this.onBack,
        color: this.color,
        isShowAppBar: this.isShowAppBar,
        actionAppbar: this.actionAppbar);
  }

  @override
  Widget getMainView(BuildContext context,
      Map<String, List<Map<String, Object>>> data, BaseController controller) {
    return _getEditorView(context, controller);
  }

  bool validate({int step, bool isShowInvalidDialog}) {
    return _editorController.validate(
        step: step, isShowInvalidDialog: isShowInvalidDialog);
  }

  void onValueChanged(String fieldName, Object value) {
    _editorController.onValueChanged(fieldName, value);
  }

  void onSave() {
    _editorController.save();
  }
}

class EditorItem {
  final String fieldName;
  final Object defaultValue;
  final int step;
  final EEditorType type;
  final String titleMesageId;
  String title;
  String hint;
  String inValidMessage;
  bool isRequired = true;
  final String Function(Object value) validator;
  final UploadImageInfo uploadImageInfo;

  EditorItem({
    @required this.fieldName,
    this.type,
    this.step,
    this.titleMesageId,
    this.validator,
    this.uploadImageInfo,
    this.defaultValue,
    bool isRequired,
  }) {
    if (this.titleMesageId != null) {
      title = Message.getMessage(this.titleMesageId);
      hint = Message.getMessage('HINT_MESSAGE-' + this.titleMesageId);
    }

    //ưu tiên lấy theo isRequired nếu có khai báo, còn không check theo title
    if (isRequired == null) isRequired = false;
    if (!isRequired && title != null && this.title.isNotEmpty) {
      this.isRequired = this.title.startsWith('*') ||
          this.title.endsWith('*') ||
          this.title.startsWith('(*)') ||
          this.title.endsWith('(*))');
    }
    if (this.isRequired) {
      inValidMessage =
          Message.getMessage('INVALID_MESSAGE-' + this.titleMesageId);
    }
  }
}

enum EEditorType {
  image,
  int,
  double,
  string,
  money,
  phone,
  email,
  datetime,
}

class UploadImageInfo {
  final String tableName, fieldName, parentTableName, responseIdsName;

  UploadImageInfo({
    @required this.tableName,
    @required this.fieldName,
    this.parentTableName,
    @required this.responseIdsName,
  });
}

==> wowit-0.3.160.tar.gz: lib/Widget/editor_widget/editor_widget.dart <==
import 'package:flutter/material.dart';
import 'package:get/get.dart';
import 'package:wowit/Controller/baseController.dart';
import 'package:wowit/Widget/baseWidgets.dart';

import '../../message.dart';
import 'view/editor_screen.dart';

abstract class EditorWidget<T extends BaseController> extends BaseWidget<T> {
  final String title;
  final Color color;
  final bool isShowAppBar;
  final EditorController _editorController;
  final List<Widget> actionAppbar;

  EditorWidget(
    BaseController baseController, {
    Key key,
    this.title,
    this.color,
    this.isShowAppBar = true,
    List<EditorItem> editorItems,
    Map<String, Object> initialDataEntity,
    @required String onSaveProcedure,
    this.actionAppbar,
  })  : _editorController =
            EditorController(initialDataEntity, onSaveProcedure, editorItems),
        super(baseController as T);

  Widget getEditorControlView(BuildContext buildContext,
      EditorController editorController, BaseController baseController);

  void onBack() {
    Get.back();
  }

  Widget _getEditorView(BuildContext context, BaseController baseController) {
    return EditorScreen(
        editorControlView:
            getEditorControlView(context, _editorController, baseController),
        editorController: _editorController,
        title: this.title,
        onBack: this.onBack,
        color: this.color,
        isShowAppBar: this.isShowAppBar,
        actionAppbar: this.actionAppbar);
  }

  @override
  Widget getMainView(BuildContext context,
      Map<String, List<Map<String, Object>>> data, BaseController controller) {
    return _getEditorView(context, controller);
  }

  bool validate({int step, bool isShowInvalidDialog}) {
    return _editorController.validate(
        step: step, isShowInvalidDialog: isShowInvalidDialog);
  }

  void onValueChanged(String fieldName, Object value) {
    _editorController.onValueChanged(fieldName, value);
  }

  void onSave() {
    _editorController.save();
  }
}

class EditorItem {
  final String fieldName;
  final Object defaultValue;
  final int step;
  final EEditorType type;
  String titleMesageId;
  String _title;
  String getTitle() {
    if (_title == null) {
      _title = Message.getMessage(this.titleMesageId);
    }
    return _title;
  }

  String _hint;
  String getHint() {
    if (_hint == null) {
      _hint =
          Message.getMessage('EditorItem-HINT_MESSAGE-' + this.titleMesageId);
    }
    return _hint;
  }

  String _inValidMessage;
  String getInValidMessage() {
    if (_inValidMessage == null) {
      _inValidMessage = Message.getMessage(
          'EditorItem-INVALID_MESSAGE-' + this.titleMesageId);
    }
    return _inValidMessage;
  }

  bool isRequired = true;
  final String Function(Object value) validator;
  final UploadImageInfo uploadImageInfo;

  EditorItem({
    @required this.fieldName,
    this.type,
    this.step,
    this.titleMesageId,
    this.validator,
    this.uploadImageInfo,
    this.defaultValue,
    bool isRequired,
  }) {
    if (titleMesageId == null) {
      titleMesageId = "EditorItem";
      if (this.type != null) {
        titleMesageId += "-" + this.type.toString();
      }
      titleMesageId += this.fieldName;
    }
    //ưu tiên lấy theo isRequired nếu có khai báo, còn không check theo title
    if (isRequired == null) isRequired = false;
    if (!isRequired) {
      this.isRequired = this.getTitle().startsWith('*') ||
          this.getTitle().endsWith('*') ||
          this.getTitle().startsWith('(*)') ||
          this.getTitle().endsWith('(*))');
    }
  }
}

enum EEditorType {
  image,
  int,
  double,
  string,
  money,
  phone,
  email,
  datetime,
}

class UploadImageInfo {
  final String tableName, fieldName, parentTableName, responseIdsName;

  UploadImageInfo({
    @required this.tableName,
    @required this.fieldName,
    this.parentTableName,
    @required this.responseIdsName,
  });
}
